==> kadu_0.11.0.orig.tar.bz2: kadu-0.11.0/plugins/antistring/translations/antistring_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="4"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="7"/>
        <source>Antistring</source>
        <translation>Anti-Schneeball-System</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="10"/>
        <source>General</source>
        <translation>Allgemeines</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="13"/>
        <source>Enable Antistring</source>
        <translation>Anti-Schneeball-System einschalten</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="16"/>
        <source>Block message</source>
        <translation>Blockieren Sie die Nachricht</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="19"/>
        <source>Admonition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="24"/>
        <location filename="../.configuration-ui-translations.cpp" line="30"/>
        <source>Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="27"/>
        <source>Write log to file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="35"/>
        <source>Conditions</source>
        <translation>Bedingungen</translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <location filename="../antistring.cpp" line="118"/>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="80"/>
        <source>Condition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="86"/>
        <source>Don&apos;t use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="87"/>
        <source>Factor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="90"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="91"/>
        <source>Change</source>
        <translation>Änderung</translation>
    </message>
    <message>
        <location filename="../antistring-configuration-ui-handler.cpp" line="92"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <location filename="../antistring-notification.cpp" line="43"/>
        <source>Antistring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../antistring-notification.cpp" line="44"/>
        <source>Your interlocutor send you love letter</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> kadu-0.12.2.tar.bz2: kadu-0.12.2/plugins/antistring/translations/antistring_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Anti-Schneeball-System</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemeines</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Anti-Schneeball-System einschalten</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Blockieren Sie die Nachricht</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Bedingungen</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Änderung</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation type="unfinished">Anti-Schneeball-System</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
